@@ -4,14 +4,14 @@ use Exporter;
 our @ISA    = qw(Exporter);
 our @EXPORT = qw(
   is_atom is_atom_name is_false is_match is_true is_bool
-  is_sym is_token is_rept is_look
-  is_tillnot is_str is_expr);
+  is_atom_sym is_atom_token is_atom_rept is_atom_look
+  is_atom_tillnot is_atom_str is_atom_expr);
 
 use Spp::Builtin;
 
 sub is_atom {
    my $x = shift;
-   return (is_perl_array($x) and is_perl_str($x->[0]));
+   return (is_array($x) and is_str($x->[0]));
 }
 
 sub is_atom_name {
@@ -39,27 +39,27 @@ sub is_bool {
    return (is_false($atom) or is_true($atom));
 }
 
-sub is_sym {
+sub is_atom_sym {
    my $atom = shift;
    return is_atom_name($atom, 'Sym');
 }
 
-sub is_token {
+sub is_atom_token {
    my $atom = shift;
    return is_atom_name($atom, 'Token');
 }
 
-sub is_rept {
+sub is_atom_rept {
    my $atom = shift;
    return is_atom_name($atom, '_rept');
 }
 
-sub is_look {
+sub is_atom_look {
    my $atom = shift;
    return is_atom_name($atom, '_look');
 }
 
-sub is_tillnot {
+sub is_atom_tillnot {
    my $s = shift;
    if (is_atom($s)) {
       return 1 if $s->[0] eq 'Till';
@@ -68,12 +68,12 @@ sub is_tillnot {
    return 0;
 }
 
-sub is_str {
+sub is_atom_str {
    my $atom = shift;
    return is_atom_name($atom, 'Str');
 }
 
-sub is_expr {
+sub is_atom_expr {
    my $atom = shift;
    return is_atom_name($atom, 'Expr');
 }
