@@ -1,34 +1,16 @@
 package Spp::Match;
 
-use Exporter;
-our @ISA    = qw(Exporter);
-our @EXPORT = qw(match match_rule);
-
 use 5.012;
 no warnings "experimental";
+
+use Exporter;
+our @ISA    = qw(Exporter);
+our @EXPORT = qw(match_rule);
+
 use Spp::Builtin;
 use Spp::Cursor;
 use Spp::IsChar;
 use Spp::IsAtom;
-use Spp::ToSpp qw(to_spp);
-
-sub match {
-   my ($parser, $text, $mode) = @_;
-   my ($door, $table) = @{$parser};
-   my $cursor = cursor($text, $table);
-   my $door_rule = $cursor->{ns}{$door};
-   if (defined $mode) { $cursor->{debug} = $mode }
-   my $match = match_rule($door_rule, $cursor);
-   if (is_false($match)) {
-      my $max_report = max_report($cursor);
-      return ['false', $max_report];
-   }
-   return $match if is_true($match);
-   my $char = first($door);
-   return [$door, $match] if is_upper($char);
-   return $match if is_lower($char);
-   return ['true'] if $char eq '_';
-}
 
 sub match_rule {
    my ($rule, $cursor) = @_;
@@ -37,7 +19,7 @@ sub match_rule {
       when ('Rules') { match_rules($value, $cursor) }
       when ('Group') { match_rules($value, $cursor) }
       when ('Branch') { match_branch($value, $cursor) }
-      when ('Lbranch') { match_lbranch($value, $cursor) }
+      when ('Lbranch'){ match_lbranch($value, $cursor) }
       when ('Rept') { match_rept($value, $cursor) }
       when ('Look') { match_look($value, $cursor) }
       when ('Cclass') { match_cclass($value, $cursor) }
@@ -54,56 +36,14 @@ sub match_rule {
       when ('Any') { match_any($value, $cursor) }
       when ('Expr') { match_expr($value, $cursor) }
       when ('Sym') { match_sym($value, $cursor) }
-      default { die "unknown rule type $name to match" }
-   }
-}
-
-sub _match_rule {
-   my ($x_rule, $cursor) = @_;
-   if ($cursor->{debug} == 1) {
-      my $name = $x_rule->[0];
-
-      # do not need trace rule
-      if ($name ~~
-         ['Group', 'Rept', 'Look', 'Branch', 'Lbranch', 'Ctoken'])
-      {
-         return _match_rule($x_rule, $cursor);
-      }
-      my $off    = $cursor->{off};
-      my $str    = $cursor->{str};
-      my $rule   = to_spp($x_rule);
-      my $flag   = '->';
-      my $char   = char_to_see(substr($str, $off, 1));
-      my $indent = ' ' x $cursor->{depth};
-      my $log    = "$off $char $indent $flag $rule";
-      $cursor->{depth}++;
-      my $match = _match_rule($x_rule, $cursor);
-      $cursor->{depth}--;
-      if (is_match($match)) { return $match }
-      say $log;
-      return $match;
-   }
-   else {
-      return _match_rule($x_rule, $cursor);
-   }
-}
-
-sub char_to_see {
-   my $char = shift;
-   given ($char) {
-      when ("\n")   { return '\n' }
-      when ("\r")   { return '\r' }
-      when ("\t")   { return '\t' }
-      when (" ")    { return '\s' }
-      when (chr(0)) { return '\0' }
-      default       { return " $char" }
+      default { die "unknown rule type $name to match!" }
    }
 }
 
 sub match_any {
    my ($any, $cursor) = @_;
    my $char = get_char($cursor);
-   return ['false'] if $char eq chr(0);
+   if ($char eq chr(0)) { return ['false'] }
    go($cursor);
    return $char;
 }
@@ -129,7 +69,7 @@ sub match_assert {
          return ['true'] if get_char($cursor) eq chr(0);
          return ['false'];
       }
-      default { die("die assert char: |$assert|") }
+      default { die "error assert char: <$assert>!" }
    }
 }
 
@@ -149,10 +89,8 @@ sub match_branch {
    my $cache = cache($cursor);
    for my $rule (@{$branch}) {
       my $match = match_rule($rule, $cursor);
-      if (is_false($match)) {
-         recover($cursor, $cache);
-      }
-      else { return $match }
+      if (is_match($match)) { return $match }
+      recover($cursor, $cache);
    }
    return ['false'];
 }
@@ -180,39 +118,36 @@ sub match_ntoken {
    my ($name, $cursor) = @_;
    my $rule  = $cursor->{ns}->{$name};
    my $cache = cache($cursor);
-   my $from  = $cache->[1];
    my $match = match_rule($rule, $cursor);
    return $match if is_bool($match);
-   my $len    = $cursor->{off} - $from;
-   my $str    = substr($cursor->{str}, $from, $len);
-   my $c_name = '$' . $name;
-   $cursor->{ns}->{$c_name} = ['Str', $str];
-
-   if ($cursor->{debug} == 2) {
+   my $from  = $cache->[1];
+   my $len   = $cursor->{off} - $from;
+   my $str   = substr($cursor->{str}, $from, $len);
+   my $cname = '$' . $name;
+   $cursor->{ns}->{$cname} = ['Str', $str];
+   if ($cursor->{'mode'} != 0) {
       push @{$cache}, $len;
-      return name_match($name, $match, $cache);
-   }
-   else {
-      return name_match($name, $match);
+      return name_match_pos($name, $match, $cache);
    }
+   return name_match($name, $match);
 }
 
 sub match_ctoken {
    my ($name, $cursor) = @_;
-   my $rule  = $cursor->{ns}->{$name};
-   my $cache = $cursor->{off};
+   my $rule  = $cursor->{'ns'}{$name};
+   my $from  = $cursor->{'off'};
    my $match = match_rule($rule, $cursor);
    return $match if is_bool($match);
-   my $len    = $cursor->{off} - $cache;
-   my $str    = substr($cursor->{str}, $cache, $len);
-   my $c_name = '$' . $name;
-   $cursor->{ns}->{$c_name} = ['Str', $str];
+   my $len   = $cursor->{'off'} - $from;
+   my $str   = substr($cursor->{'str'}, $from, $len);
+   my $cname = '$' . $name;
+   $cursor->{'ns'}{$cname} = ['Str', $str];
    return $match;
 }
 
 sub match_rtoken {
    my ($name, $cursor) = @_;
-   my $rule = $cursor->{ns}->{$name};
+   my $rule = $cursor->{ns}{$name};
    my $match = match_rule($rule, $cursor);
    return ['false'] if is_false($match);
    return ['true'];
@@ -220,10 +155,10 @@ sub match_rtoken {
 
 sub match_not {
    my ($rule, $cursor) = @_;
-   my $cache = $cursor->{off};
+   my $cache = cache($cursor);
    my $match = match_rule($rule, $cursor);
    if (is_false($match)) {
-      $cursor->{off} = $cache;
+      recover($cursor, $cache);
       return ['true'];
    }
    return ['false'];
@@ -231,32 +166,26 @@ sub match_not {
 
 sub match_till {
    my ($rule, $cursor) = @_;
-
-   # say to_json($rule);
    my @buf = ();
-
-   # could not reach chr(0) how to match $
    while ($cursor->{off} < $cursor->{len}) {
       my $char = get_char($cursor);
       my $match = match_rule($rule, $cursor);
-
-      # say "<$char>";
-      if (is_false($match)) {
-         push @buf, $char;
-         go($cursor);
-      }
-      else {
-         return gather_match(join('', @buf), $match);
+      if (is_match($match)) {
+         my $gather_str - join '', @buf;
+         return gather_match($gather_str, $match);
       }
+      push @buf, $char;
+      go($cursor);
    }
    return ['false'];
 }
 
 sub match_rept {
-   my ($rule,   $cursor) = @_;
-   my ($gather, $time)   = (['true'], 0);
-   my ($rept,   $atom)   = @{$rule};
-   my ($min,    $max)    = get_rept_time($rept);
+   my ($rule, $cursor) = @_;
+   my $gather = ['true'];
+   my $time   = 0;
+   my ($rept, $atom) = @{$rule};
+   my ($min,  $max)  = get_rept_time($rept);
    while ($time != $max) {
       my $cache = cache($cursor);
       my $match = match_rule($atom, $cursor);
@@ -273,18 +202,20 @@ sub match_rept {
 
 sub get_rept_time {
    my $rept = shift;
-   return (0, 1)  if $rept eq '?';
-   return (0, -1) if $rept eq '*';
-   return (1, -1) if $rept eq '+';
-   return (0, -1) if $rept eq '*?';
-   return (1, -1) if $rept eq '+?';
+   given ($rept) {
+      when ('?')  { return (0,  1) }  
+      when ('*')  { return (0, -1) } 
+      when ('+')  { return (1, -1) } 
+      when ('*?') { return (0, -1) }
+      when ('+?') { return (1, -1) }
+      default { die "error rept str: <$rept>!" }
+   }
 }
 
 sub match_look {
-   my ($rule,   $cursor) = @_;
-   my ($rept,   @atoms)  = @{$rule};
-   my ($min,    $max)    = get_rept_time($rept);
-   my ($atom,   $look)   = @atoms;
+   my ($rule, $cursor) = @_;
+   my ($rept, $atom, $look) = @{$rule};
+   my ($min, $max) = get_rept_time($rept);
    my ($gather, $time)   = (['true'], 0);
    while ($time != $max) {
       my $cache = cache($cursor);
@@ -301,8 +232,10 @@ sub match_look {
       if ($time >= $min) {
          $cache = cache($cursor);
          $match = match_rule($look, $cursor);
-         if (is_false($match)) { recover($cursor, $cache) }
-         else { return gather_match($gather, $match) }
+         if (is_match($match)) {
+            return gather_match($gather, $match)
+         }
+         recover($cursor, $cache);
       }
    }
    return ['false'];
@@ -310,12 +243,8 @@ sub match_look {
 
 sub match_str {
    my ($str, $cursor) = @_;
-   my $cache = cache($cursor);
    for my $char (split('', $str)) {
-      if ($char ne get_char($cursor)) {
-         recover($cursor, $cache);
-         return ['false'];
-      }
+      if ($char ne get_char($cursor)) { return ['false'] }
       go($cursor);
    }
    return $str;
@@ -355,10 +284,10 @@ sub match_catom {
    my ($atom, $char)  = @_;
    my ($name, $value) = @{$atom};
    given ($name) {
-      when ("Range") { return match_range($value, $char) }
-      when ("Cclass") { return is_match_cclass($value, $char) }
-      when ("Char")   { return $value eq $char }
-      default         { die("unknown chclass node: <$name>") }
+      when ("Range") { match_range($value, $char) }
+      when ("Cclass") { is_match_cclass($value, $char) }
+      when ("Char") { return $value eq $char }
+      default { die("unknown chclass node: <$name>!") }
    }
 }
 
@@ -376,32 +305,32 @@ sub match_cclass {
 sub is_match_cclass {
    my ($cchar, $char) = @_;
    given ($cchar) {
-      when ('a') { return is_alpha($char) }
-      when ('A') { return !is_alpha($char) }
-      when ('d') { return is_digit($char) }
-      when ('D') { return !is_digit($char) }
-      when ('h') { return is_hspace($char) }
-      when ('H') { return !is_hspace($char) }
-      when ('l') { return is_lower($char) }
-      when ('L') { return !is_lower($char) }
-      when ('s') { return is_space($char) }
-      when ('S') { return !is_space($char) }
-      when ('u') { return is_upper($char) }
-      when ('U') { return !is_upper($char) }
-      when ('v') { return is_vspace($char) }
-      when ('V') { return !is_vspace($char) }
-      when ('w') { return is_words($char) }
-      when ('W') { return !is_words($char) }
-      when ('x') { return is_xdigit($char) }
-      when ('X') { return !is_xdigit($char) }
-      default    { die("unknown cclass $cchar") }
+      when ('a') { return is_char_alpha($char) }
+      when ('A') { return !is_char_alpha($char) }
+      when ('d') { return is_char_digit($char) }
+      when ('D') { return !is_char_digit($char) }
+      when ('h') { return is_char_hspace($char) }
+      when ('H') { return !is_char_hspace($char) }
+      when ('l') { return is_char_lower($char) }
+      when ('L') { return !is_char_lower($char) }
+      when ('s') { return is_char_space($char) }
+      when ('S') { return !is_char_space($char) }
+      when ('u') { return is_char_upper($char) }
+      when ('U') { return !is_char_upper($char) }
+      when ('v') { return is_char_vspace($char) }
+      when ('V') { return !is_char_vspace($char) }
+      when ('w') { return is_char_words($char) }
+      when ('W') { return !is_char_words($char) }
+      when ('x') { return is_char_xdigit($char) }
+      when ('X') { return !is_char_xdigit($char) }
+      default    { die "unknown cclass $cchar" }
    }
 }
 
 sub match_range {
-   my ($range,     $char)    = @_;
-   my ($from_char, $to_char) = @{$range};
-   return ($from_char le $char && $char le $to_char);
+   my ($range, $char) = @_;
+   my ($from,  $to) = @{$range};
+   return ($from le $char && $char le $to);
 }
 
 sub match_expr {
@@ -413,9 +342,13 @@ sub match_expr {
 sub match_sym {
    my ($name, $cursor) = @_;
    my $value = eval_sym($name, $cursor->{ns});
-
-   # say to_json($value);
-   return match_atom($value, $cursor);
+   my $match = match_atom($value, $cursor);
+   if (is_false($match)) { return $match }
+   my $token_name = rest($name);
+   my $char = first($token_name);
+   if (is_char_upper($char)) { return [$token_name, $match] }
+   if ($char eq '_') { return ['true'] }
+   return $match;
 }
 
 sub match_atom {
@@ -432,25 +365,20 @@ sub match_atom {
 sub match_array {
    my ($array, $cursor) = @_;
    return ['false'] if len($array) == 0;
-   if (all { is_str($_) } @{$array}) {
-      return match_lbranch($array, $cursor);
-   }
-   say to_json($array);
-   die("match array include not Str Atom");
+   return match_lbranch($array, $cursor);
+}
+
+sub name_match_pos {
+   my ($name, $match, $pos) = @_;
+   if (is_true($match)) { return $match }
+   if (is_atom($match)) { return [$name, [$match], $pos] }
+   return [$name, $match, $pos];
 }
 
 sub name_match {
-   my ($name, $match, $pos) = @_;
-   return $match if is_true($match);
-   if (is_atom($match)) {
-      if (defined $pos) {
-         return [$name, [$match], $pos];
-      }
-      return [$name, [$match]];
-   }
-   if (defined $pos) {
-      return [$name, $match, $pos];
-   }
+   my ($name, $match) = @_;
+   if (is_true($match)) { return $match }
+   if (is_atom($match)) { return [$name, [$match]] }
    return [$name, $match];
 }
 
@@ -458,11 +386,11 @@ sub gather_match {
    my ($gather, $match) = @_;
    return $gather if is_true($match);
    return $match  if is_true($gather);
-   if (is_perl_str($match)) {
-      return $gather . $match if is_perl_str($gather);
+   if (is_str($match)) {
+      return $gather . $match if is_str($gather);
       return $gather;
    }
-   if (is_perl_str($gather)) { return $match }
+   if (is_str($gather)) { return $match }
    if (is_atom($gather)) {
       return [$gather, $match] if is_atom($match);
       return [$gather, @{$match}];
@@ -473,86 +401,78 @@ sub gather_match {
 
 sub eval_atom {
    my ($atom, $ns) = @_;
-   if (!is_atom($atom)) {
-      say to_json($atom);
-      die("not atom to eval $atom");
-   }
    my ($name, $value) = @{$atom};
    given ($name) {
       when ('Str')   { return $atom }
       when ('Sym')   { return eval_sym($value, $ns) }
       when ('Expr')  { return eval_expr($value, $ns) }
       when ('Array') { return eval_array($value, $ns) }
-      default {
-         # say to_json($atom);
-         die("Not implement eval atom $name");
-      }
+      default { die "Could not eval atom: <$name>!"; }
    }
 }
 
 sub eval_sym {
    my ($name, $ns) = @_;
    if (exists $ns->{$name}) { return $ns->{$name} }
-   die("variable not define: $name");
+   die "variable not define: <$name>.";
 }
 
 sub eval_expr {
    my ($expr, $ns) = @_;
    my $name = shift @{$expr};
    given ($name) {
-      when ("push") { return eval_push($expr, $ns) }
-      when ("my") { return eval_my($expr, $ns) }
-      when ("say") { return eval_say($expr, $ns) }
-      default { warn("not implement action: $name") }
+      when ('push') { eval_push($expr, $ns) }
+      when ('my') { eval_my($expr, $ns) }
+      when ('say') { eval_say($expr, $ns) }
+      default { die "not implement action: <$name>."; }
    }
 }
 
 sub eval_array {
    my ($array, $ns) = @_;
-   if (len($array) == 0) { return ["Array", $array] }
+   if (len($array) == 0) {
+      return ['Array', $array]
+   }
    my $atoms = eval_atoms($array, $ns);
-   return ["Array", $atoms];
+   return ['Array', $atoms];
 }
 
 sub eval_push {
    my ($atoms, $ns) = @_;
    my $sym = $atoms->[0];
-   if (!is_sym($sym)) {
-      die("push only accept symbol");
+   if (is_atom_sym($sym)) {
+      my $eval_atoms = eval_atoms($atoms, $ns);
+      my ($array, $element) = @{$eval_atoms};
+      push @{ $array->[1] }, $element;
+      my $name = $sym->[1];
+      $ns->{$name} = $array;
+      return ['true'];
    }
-   my $name = $sym->[1];
-   my $eval_atoms = eval_atoms($atoms, $ns);
-   my ($array, $element) = @{$eval_atoms};
-   push @{ $array->[1] }, $element;
-   $ns->{$name} = $array;
-   return ['true'];
+   die 'push only accept array symbol!';
 }
 
-# return should is die nil or some die tips
 sub eval_my {
    my ($atoms, $ns) = @_;
    my $sym = $atoms->[0];
    my $value = eval_atom($atoms->[1], $ns);
-   if (is_sym($sym)) {
+   if (is_atom_sym($sym)) {
       my $name = $sym->[1];
       $ns->{$name} = $value;
       return ['true'];
    }
-   else {
-      die("only assign symbol");
-   }
+   die 'only assign symbol!';
 }
 
 sub eval_say {
    my ($atoms, $ns) = @_;
    my $eval_atoms = eval_atoms($atoms, $ns);
-   my $str = first($eval_atoms);
-   if (is_str($str)) {
+   my $str = $eval_atoms->[0];
+   if (is_atom_str($str)) {
       say $str->[1];
       return ['true'];
    }
    my $type = $str->[0];
-   die("say only accept Str: |$type|");
+   die "say only accept Str: <$type>";
 }
 
 sub eval_atoms {
